aboutsummaryrefslogtreecommitdiffhomepage
path: root/include/core
diff options
context:
space:
mode:
authorGravatar bsalomon@google.com <bsalomon@google.com@2bbb7eff-a529-9590-31e7-b0007b416f81>2012-10-24 20:11:30 +0000
committerGravatar bsalomon@google.com <bsalomon@google.com@2bbb7eff-a529-9590-31e7-b0007b416f81>2012-10-24 20:11:30 +0000
commit8ea78d83dc4e8243c16eedf8100a3987c54123fa (patch)
tree9ba446bd394cbd266cc01c099ee8725603069d6d /include/core
parentf271cc7183fe48ac64d2d9a454eb013c91b42d53 (diff)
GrCustomStage Renaming Part 4
Rename a bunch of things found by searching for "custom". Review URL: https://codereview.appspot.com/6765048 git-svn-id: http://skia.googlecode.com/svn/trunk@6085 2bbb7eff-a529-9590-31e7-b0007b416f81
Diffstat (limited to 'include/core')
-rw-r--r--include/core/SkColorFilter.h2
-rw-r--r--include/core/SkImageFilter.h4
-rw-r--r--include/core/SkShader.h4
3 files changed, 5 insertions, 5 deletions
diff --git a/include/core/SkColorFilter.h b/include/core/SkColorFilter.h
index d470672a3f..b54d5f5d21 100644
--- a/include/core/SkColorFilter.h
+++ b/include/core/SkColorFilter.h
@@ -118,7 +118,7 @@ public:
/** A subclass may implement this factory function to work with the GPU backend. If the return
is non-NULL then the caller owns a ref on the returned object.
*/
- virtual GrEffect* asNewCustomStage(GrContext*) const;
+ virtual GrEffect* asNewEffect(GrContext*) const;
SK_DECLARE_FLATTENABLE_REGISTRAR_GROUP()
protected:
diff --git a/include/core/SkImageFilter.h b/include/core/SkImageFilter.h
index f37d5a39fa..4c7501979f 100644
--- a/include/core/SkImageFilter.h
+++ b/include/core/SkImageFilter.h
@@ -90,12 +90,12 @@ public:
* in it. The caller assumes ownership of the stage, and it is up to the
* caller to unref it.
*/
- virtual bool asNewCustomStage(GrEffect** stage, GrTexture*) const;
+ virtual bool asNewEffect(GrEffect** stage, GrTexture*) const;
/**
* Returns true if the filter can be processed on the GPU. This is most
* often used for multi-pass effects, where intermediate results must be
* rendered to textures. For single-pass effects, use asNewCustomStage().
* The default implementation returns false.
*/
virtual bool canFilterImageGPU() const;
@@ -90,12 +90,12 @@ public:
* Returns true if the filter can be processed on the GPU. This is most
* often used for multi-pass effects, where intermediate results must be
- * rendered to textures. For single-pass effects, use asNewCustomStage().
+ * rendered to textures. For single-pass effects, use asNewEffect().
* The default implementation returns false.
*/
diff --git a/include/core/SkShader.h b/include/core/SkShader.h
index 23e095029b..7329c1bf4c 100644
--- a/include/core/SkShader.h
+++ b/include/core/SkShader.h
@@ -307,12 +307,12 @@ public:
/**
* If the shader subclass has a GrEffect implementation, this installs
* a custom stage on the sampler. A GrContext pointer is required since custom
* stages may need to create textures. The sampler parameter is necessary to set a
* texture matrix. It will eventually be removed and this function will operate as a
* GrEffect factory.
*/
- virtual bool asNewCustomStage(GrContext* context, GrSamplerState* sampler) const;
+ virtual bool asNewEffect(GrContext* context, GrSamplerState* sampler) const;
//////////////////////////////////////////////////////////////////////////
// Factory methods for stock shaders
@@ -307,12 +307,12 @@ public:
/**
* If the shader subclass has a GrEffect implementation, this installs
- * a custom stage on the sampler. A GrContext pointer is required since custom
+ * an effect on the sampler. A GrContext pointer is required since custom
* stages may need to create textures. The sampler parameter is necessary to set a
* texture matrix. It will eventually be removed and this function will operate as a